@@ -18,7 +18,13 @@ const MAX_SCORE: Score = 100;
 
 type Index = usize;
 
-type VariantsList = Vec<(usize, Variants)>;
+pub type VariantsList = Vec<(usize, Variants)>;
+
+pub fn rich_dict_to_variants_list(dict: &RichDict) -> VariantsList {
+    dict.iter()
+        .map(|(id, entry)| (*id, entry.variants.clone()))
+        .collect()
+}
 
 /// Manners of articulation of initials
 ///
